
*Stay tuned for library updates and new releases on our site.* `py-orm.com/chapter/django-postgresql-func <https://py-orm.com/chapter/django-postgresql-func>`_.

=====================================================================================================================
django-postgresql-func: PostgreSQL Functions and Operators for Django. Full support for classic Django SQL functions
=====================================================================================================================

-------------------
Installing
-------------------

You can install or upgrade django-postgresql-func with:

.. code:: shell

    $ pip install django-postgresql-func --upgrade

Or you can install from source with:

.. code:: shell

    $ git clone https://github.com/lampofearth/django-postgresql-func --recursive
    $ cd django-postgresql-func
    $ python setup.py install


-------------------
Examples
-------------------

``django-postgresql-func``'s examples lives at `py-orm.com/chapter/django-postgresql-func <https://py-orm.com/chapter/django-postgresql-func>`_.

-------------------
License
-------------------

You may copy, distribute and modify the software provided that modifications
are described and licensed for free under `LGPL-3 <https://www.gnu.org/licenses/lgpl-3.0.html>`_.
Derivatives works (including modifications or anything statically linked to the library)
can only be redistributed under LGPL-3, but applications that use the library don't have to be.
